@@ -292,8 +292,8 @@ class TFCombineAffine(TFRandomTransform):
             probability: float = 0.7,
             seed: Optional[int] = None
     ) -> None:
-        not_affine_trans = filter(lambda t: not t.is_affine, transforms)
-        if not not_affine_trans:
+        not_affine_trans = list(filter(lambda t: not t.is_affine, transforms))
+        if not_affine_trans:
             raise AssertionError(
                 f"Non-affine transforms cannot be included in TFCombineAffine: "
                 f"{[t.name for t in not_affine_trans]}"
